==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/messages/pt/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Confirmar</strong> Acção',
    '<strong>Latest</strong> updates' => '<strong>Últimas</strong> actualizações',
    '<strong>Mail</strong> summary' => '<strong>E-Mail</strong> com resumos',
    'Account settings' => 'Configurações da Conta',
    'Actions' => 'Acções',
    'Add:' => 'Juntar:',
    'Administration' => 'Administração',
    'All' => 'Todos',
    'Allow' => 'Permitir',
    'An error occurred while handling your last action. (Handler not found).' => 'Ocorreu um erro a lidar com a tua acção mais recente. (Causa não encontrada).',
    'An unexpected error occurred while loading the search result.' => 'Ocorreu um erro inesperado a carregar o resultado da pesquisa.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Ocorreu um erro inesperado. Se este for persistente, por favor contacta a administração da página.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Ocorreu um erro inesperado no servidor. Se este for persistente, por favor contacta a administração da página.',
    'An unknown error occurred while uploading.' => 'Ocorreu um erro desconhecido durante o envio de ficheiros.',
    'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'Ocorreu um erro desconhecido durante o envio de ficheiros. Pista: verifica o tamanho máximo de ficheiros nas opções upload_max_filesize e post_max_size do php.',
    'Back' => 'Voltar',
    'Back to dashboard' => 'Voltar para o painel',
    'Cancel' => 'Cancelar',
    'Choose language:' => 'Escolher língua:',
    'Close' => 'Fechar',
    'Collapse' => 'Recolher',
    'Confirm' => 'Confirmar',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Fonte de conteúdo de addon deve ser exemplo de HActiveRecordContent ou HActiveRecordContentAddon!',
    'Copy to clipboard' => 'Copiar para Área de Transferência',
    'Could not find content of addon!' => 'Não é possivel encontrar o conteúdo do addon!',
    'Could not find requested page.' => 'Não foi possível encontrar a página pedida.',
    'Default' => 'Padrão',
    'Delete' => 'Apagar',
    'Deny' => 'Recusar',
    'Do you really want to perform this action?' => 'Tens a certeza que queres proceder com esta ação?',
    'Edit' => 'Editar',
    'Error' => 'Erro',
    'Error while running your last action (Invalid request method).' => 'Erro durante a execução da tua acção mais recente (Pedido realizado de modo inválido).',
    'Error:' => 'Erro:',
    'Expand' => 'Expandir',
    'Export' => 'Exportar',
    'Info:' => 'Informações:',
    'Invalid request method!' => 'Pedido realizado de modo inválido!',
    'It looks like you may have taken the wrong turn.' => 'Parece que te perdeste no caminho.',
    'Language' => 'Língua',
    'Loading...' => 'A Carregar...',
    'Login' => 'Entrar',
    'Logo of {appName}' => 'Logótipo de {appName}',
    'Logout' => 'Sair',
    'Menu' => 'Menu',
    'Module is not enabled on this content container!' => 'O módulo não está activo neste contentor!',
    'My profile' => 'O meu perfil',
    'New profile image' => 'Nova imagem de perfil',
    'Next' => 'Seguinte',
    'No error information given.' => 'Não foi dada informação de erro.',
    'Oooops...' => 'Uuuups...',
    'Open' => 'Abrir',
    'Please type at least 3 characters' => 'Por favor digita pelo menos 3 caracteres',
    'Please type at least {count} characters' => 'Por favor digita pelo menos {count} caracteres',
    'Powered by {name}' => 'Capacitado por {name}',
    'Profile dropdown' => 'Menu de perfil',
    'Profile picture of {displayName}' => 'Imagem de perfil de {displayName}',
    'Save' => 'Guardar',
    'Saved' => 'Guardado',
    'Search' => 'Pesquisar',
    'Select Me' => 'Seleccionar-me a mim',
    'Show less' => 'Mostrar menos',
    'Show more' => 'Mostrar mais',
    'Some files could not be uploaded:' => 'Não foi possível enviar alguns ficheiros:',
    'Text could not be copied to clipboard' => 'Não foi possível copiar o texto para a Área de Transferência',
    'Text has been copied to clipboard' => 'O texto foi copiado para a Área de Transferência',
    'The date has to be in the past.' => 'A data deve estar no passado.',
    'The file has been deleted.' => 'O ficheiro foi apagado.',
    'The requested resource could not be found.' => 'Foi impossível encontrar o recurso pedido.',
    'The space has been archived.' => 'O espaço foi arquivado.',
    'The space has been unarchived.' => 'O espaço foi desarquivado.',
    'Time Zone' => 'Fuso Horário',
    'Toggle comment menu' => 'Alternar menu de comentários',
    'Toggle panel menu' => 'Alternar menu do painel',
    'Toggle post menu' => 'Alternar menu do artigo',
    'Toggle stream entry menu' => 'Alternar menu de entrada em stream',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Há alterações por guardar, de certeza que queres sair desta página?',
    'Unsubscribe' => 'Cancelar subscrição',
    'Upload' => 'Enviar dados',
    'Upload file' => 'Enviar ficheiro',
    'You are not allowed to run this action.' => 'Esta acção não te é permitida.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'Stop impersonation' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/messages/pt/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Confirmar</strong> Ação',
    '<strong>Latest</strong> updates' => '<strong>Últimas</strong> atualizações',
    '<strong>Mail</strong> summary' => '<strong>E-Mail</strong> com resumos',
    'Actions' => 'Ações',
    'Add:' => 'Adicionar:',
    'Administration' => 'Administração',
    'All' => 'Todos',
    'Allow' => 'Permitir',
    'Allow content from external source' => 'Permitr conteúdos de fonte externa',
    'Always allow content from this provider!' => 'Permitir sempre conteúdos desta fonte!',
    'An error occurred while handling your last action. (Handler not found).' => 'Ocorreu um erro a lidar com a tua acção mais recente. (Causa não encontrada).',
    'An unexpected error occurred while loading the search result.' => 'Ocorreu um erro inesperado a carregar o resultado da pesquisa.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Ocorreu um erro inesperado. Se este for persistente, por favor contacta a administração da página.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Ocorreu um erro inesperado no servidor. Se este for persistente, por favor contacta a administração da página.',
    'Back' => 'Voltar',
    'Back to dashboard' => 'Voltar para o painel',
    'Cancel' => 'Cancelar',
    'Choose language:' => 'Escolher língua:',
    'Close' => 'Fechar',
    'Collapse' => 'Recolher',
    'Confirm' => 'Confirmar',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Fonte de conteúdo de addon deve ser exemplo de HActiveRecordContent ou HActiveRecordContentAddon!',
    'Copy to clipboard' => 'Copiar para Área de Transferência',
    'Could not find content of addon!' => 'Não é possivel encontrar o conteúdo do addon!',
    'Could not find requested page.' => 'Não foi possível encontrar a página pedida.',
    'Default' => 'Padrão',
    'Delete' => 'Apagar',
    'Deny' => 'Recusar',
    'Do you really want to perform this action?' => 'Tens a certeza que queres proceder com esta ação?',
    'Do you want to enable content from \'{urlPrefix}\'?' => 'Desejas ativar conteúdos de {urlPrefix}\'?',
    'Edit' => 'Editar',
    'Error' => 'Erro',
    'Error while running your last action (Invalid request method).' => 'Erro durante a execução da tua acção mais recente (Pedido realizado de modo inválido).',
    'Error:' => 'Erro:',
    'Expand' => 'Expandir',
    'Export' => 'Exportar',
    'Info:' => 'Informações:',
    'Invalid request method!' => 'Pedido realizado de modo inválido!',
    'It looks like you may have taken the wrong turn.' => 'Parece que te perdeste no caminho.',
    'Language' => 'Língua',
    'Loading...' => 'A Carregar...',
    'Login' => 'Entrar',
    'Logo of {appName}' => 'Logótipo de {appName}',
    'Logout' => 'Sair',
    'Menu' => 'Menu',
    'Module is not enabled on this content container!' => 'O módulo não está activo neste contentor!',
    'New profile image' => 'Nova imagem de perfil',
    'Next' => 'Seguinte',
    'No error information given.' => 'Não foi dada informação de erro.',
    'Oooops...' => 'Uuuups...',
    'Open' => 'Abrir',
    'Please type at least 3 characters' => 'Por favor digita pelo menos 3 caracteres',
    'Please type at least {count} characters' => 'Por favor digita pelo menos {count} caracteres',
    'Powered by {name}' => 'Capacitado por {name}',
    'Profile dropdown' => 'Menu de perfil',
    'Profile picture of {displayName}' => 'Imagem de perfil de {displayName}',
    'Save' => 'Guardar',
    'Saved' => 'Guardado',
    'Search' => 'Pesquisar',
    'Search...' => 'Pesquisar...',
    'Select Me' => 'Seleccionar-me a mim',
    'Settings' => 'Configurações',
    'Show less' => 'Mostrar menos',
    'Show more' => 'Mostrar mais',
    'Some files could not be uploaded:' => 'Não foi possível enviar alguns ficheiros:',
    'Stop impersonation' => 'Para personificação',
    'Text could not be copied to clipboard' => 'Não foi possível copiar o texto para a Área de Transferência',
    'Text has been copied to clipboard' => 'O texto foi copiado para a Área de Transferência',
    'The date has to be in the past.' => 'A data deve estar no passado.',
    'The file has been deleted.' => 'O ficheiro foi apagado.',
    'The requested resource could not be found.' => 'Foi impossível encontrar o recurso pedido.',
    'The space has been archived.' => 'O espaço foi arquivado.',
    'The space has been unarchived.' => 'O espaço foi desarquivado.',
    'Time Zone' => 'Fuso Horário',
    'Toggle comment menu' => 'Alternar menu de comentários',
    'Toggle panel menu' => 'Alternar menu do painel',
    'Toggle post menu' => 'Alternar menu do artigo',
    'Toggle stream entry menu' => 'Alternar menu de entrada em stream',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Há alterações por guardar, de certeza que queres sair desta página?',
    'Unsubscribe' => 'Cancelar subscrição',
    'Upload' => 'Carregar',
    'Upload file' => 'Carregar ficheiro',
    'You are not allowed to run this action.' => 'Esta ação não te é permitida.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => '',
    'My Profile' => '',
    'verify your upload_max_filesize and post_max_size php settings.' => '',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
];
